==> v6.0.tar.gz: uhr/uhr-de.js <==
/*
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var h = {
	"_es_ist": {1:[1,2,4,5,6]},
	"_nach": {4:[8,9,10,11]},
	"_vor": {4:[1,2,3]},
	"_halb": {5:[1,2,3,4]},
	"_5": {1:[8,9,10,11]},
	"_10": {2:[1,2,3,4]},
	"_15": {3:[5,6,7,8,9,10,11]},
	"_20": {2:[5,6,7,8,9,10,11]},
	"_45": {3:[1,2,3,4,5,6,7,8,9,10,11]}
};
var layout = {
	"version": 2,
	"language": 'Deutsch',
	"letters": [
		'ESKISTAFÜNF',
		'ZEHNZWANZIG',
		'DREIVIERTEL',
		'VORFUNKNACH',
		'HALBAELFÜNF',
		'EINSXAMZWEI',
		'DREIPMJVIER',
		'SECHSNLACHT',
		'SIEBENZWÖLF',
		'ZEHNEUNKUHR'
		],
	"permanent": h._es_ist,
	"minutes": {
		"5,6,7,8,9": [h._5, h._nach],
		"10,11,12,13,14": [h._10, h._nach],
		"15,16,17,18,19": [h._15, h._nach],
		"20,21,22,23,24": [h._20, h._nach],
		"25,26,27,28,29": [h._5, h._vor, h._halb],
		"30,31,32,33,34": h._halb,
		"35,36,37,38,39": [h._5, h._nach, h._halb],
		"40,41,42,43,44": [h._20, h._vor],
		"45,46,47,48,49": h._45,
		"50,51,52,53,54": [h._10, h._vor],
		"55,56,57,58,59": [h._5, h._vor]
	},
	"hours": {
		"1": {6:[1,2,3,4]},
		"2": {6:[8,9,10,11]},
		"3": {7:[1,2,3,4]},
		"4": {7:[8,9,10,11]},
		"5": {5:[8,9,10,11]},
		"6": {8:[1,2,3,4,5]},
		"7": {9:[1,2,3,4,5,6]},
		"8": {8:[8,9,10,11]},
		"9": {10:[4,5,6,7]},
		"10": {10:[1,2,3,4]},
		"11": {5:[6,7,8]},
		"12": {9:[7,8,9,10,11]}
	}
};
window,_uhr.register('de', layout);

==> v6.2.tar.gz: uhr/uhr-de.js <==
/*
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var h = {
	"_es_ist": {1:[1,2,4,5,6]},
	"_nach": {4:[8,9,10,11]},
	"_vor": {4:[1,2,3]},
	"_halb": {5:[1,2,3,4]},
	"_5": {1:[8,9,10,11]},
	"_10": {2:[1,2,3,4]},
	"_15": {3:[5,6,7,8,9,10,11]},
	"_20": {2:[5,6,7,8,9,10,11]},
	"_45": {3:[1,2,3,4,5,6,7,8,9,10,11]}
};
var layout = {
	"version": 2,
	"language": 'Deutsch',
	"letters": [
		'ESKISTAFÜNF',
		'ZEHNZWANZIG',
		'DREIVIERTEL',
		'VORFUNKNACH',
		'HALBAELFÜNF',
		'EINSXAMZWEI',
		'DREIPMJVIER',
		'SECHSNLACHT',
		'SIEBENZWÖLF',
		'ZEHNEUNKUHR'
	],
	"permanent": h._es_ist,
	"minutes": {
		"5,6,7,8,9": [h._5, h._nach],
		"10,11,12,13,14": [h._10, h._nach],
		"15,16,17,18,19": [h._15, h._nach],
		"20,21,22,23,24": [h._20, h._nach],
		"25,26,27,28,29": [h._5, h._vor, h._halb],
		"30,31,32,33,34": h._halb,
		"35,36,37,38,39": [h._5, h._nach, h._halb],
		"40,41,42,43,44": [h._20, h._vor],
		"45,46,47,48,49": h._45,
		"50,51,52,53,54": [h._10, h._vor],
		"55,56,57,58,59": [h._5, h._vor]
	},
	"hours": {
		"0,12": {9:[7,8,9,10,11]},
		"1,13": {6:[1,2,3,4]},
		"2,14": {6:[8,9,10,11]},
		"3,15": {7:[1,2,3,4]},
		"4,16": {7:[8,9,10,11]},
		"5,17": {5:[8,9,10,11]},
		"6,18": {8:[1,2,3,4,5]},
		"7,19": {9:[1,2,3,4,5,6]},
		"8,20": {8:[8,9,10,11]},
		"9,21": {10:[4,5,6,7]},
		"10,22": {10:[1,2,3,4]},
		"11,23": {5:[6,7,8]}
	}
};
window,_uhr.register('de', layout);
